import { PDFDocumentProxy } from 'pdfjs-dist';
import { ContextMenuItem, Highlight, PdfScaleValue, PdfScrollType } from '../types';
interface PdfHighlighterOptions {
    containerElem: HTMLDivElement | null;
    highlights: Array<Highlight> | null;
    pdfScaleValue?: PdfScaleValue;
    pdfScrollType?: PdfScrollType;
    onSelection?(PdfSelection: Highlight, done?: (id: number) => void, revert?: () => void): void;
    enableAreaSelection?(event: MouseEvent): boolean;
    pdfDocument: PDFDocumentProxy;
    style?: any;
    enableAreaHighlight?: boolean;
    enableEditing?: boolean;
    enableHighlights?: boolean;
    documentContextMenuItems?: Array<ContextMenuItem>;
    highlightContextMenuItems?: Array<ContextMenuItem>;
}
declare class PdfHighlighter {
    private options;
    private pdfHighlighterContainer;
    private enableAreaHighlight;
    private enableEditing;
    private enableHighlights;
    private highlights;
    private highlightBindings;
    private highlightLayerBindings;
    private currentHighlight;
    private scrolledToHighlightId;
    private isAreaSelectionInProgress;
    private documentContextMenu;
    private highlightContextMenu;
    private currentScaleValue;
    private currentScrollType;
    private documentContextMenuItems;
    private highlightContextMenuItems;
    private eventBusPdfJs;
    private linkServicePdfJs;
    private resizeObserver;
    private pdfViewer;
    private mouseSelectionComponent;
    constructor(options: PdfHighlighterOptions);
    private initializeViewer;
    initialize(): void;
    /**
     *  Enable or disable the editing mode.
     * @param flag The flag to set the editing mode. If not provided, it will toggle the editing mode
     * @memberof PdfHighlighter
     */
    toggleEditing: (flag?: boolean) => void;
    /**
     * Toggle the highlights
     * @param flag - The flag to set the highlights. If not provided, it will toggle the highlights
     * @memberof PdfHighlighter
     */
    toggleHighlights: (flag?: boolean) => void;
    /**
     * Render highlight layers for all pages
     */
    renderHighlightLayers: () => void;
    /**
     * Scroll to a highlight
     * @param highlight - The highlight to scroll to
     */
    scrollToHighlight: (highlight: Highlight) => void;
    /**
     * Scroll to a page
     * @param pageNumber - The page number to scroll to (1-based)
     * @memberof PdfHighlighter
     */
    scrollToPage: (pageNumber: number) => void;
    /**
     * Set the scale of the PDF Viewer.
     * Accepted values are `auto`, `page-fit`, `page-width`, or a number (1 means 100%).
     */
    setScale: (scaleValue: PdfScaleValue) => void;
    /**
     * Update the highlights with the new highlights
     * It will remove the old highlights and add the new ones
     * @param highlights - The highlights to update
     * @memberof PdfHighlighter
     */
    updateHighlights: (highlights: Array<Highlight>) => void;
    /**
     * Get the highlights sorted by page number and position
     * @returns The sorted highlights
     * @memberof PdfHighlighter
     */
    getHighlights: () => Highlight[];
    /**
     * Update the context menu items
     * @param documentContextMenuItems - The new context menu items
     * @memberof PdfHighlighter
     */
    updateDocumentContextMenuItems: (documentContextMenuItems: Array<ContextMenuItem>) => void;
    /**
     * Create the HTML structure for the PdfHighlighter
     * @param container - The container element
     * @private
     * @returns The main container div
     */
    private createHTMLStructure;
    /**
     * Clear the text selection
     * @private
     */
    private clearTextSelection;
    /**
     * Copy the selected text to the clipboard
     * @param event - The keyboard event
     * @private
     * @returns void
     * @memberof PdfHighlighter
     */
    private copyTextSelection;
    /**
     * Destroy all highlight layers
     * @private
     * @returns void
     * @memberof PdfHighlighter
     */
    private destroyHighlightLayers;
    /**
     * Initialize the area highlight
     * Prepare the mouse selection component, used for area selection
     * @private
     * @returns void
     * @memberof PdfHighlighter
     */
    private initAreaHighlight;
    /**
     * Handle the context menu event
     * @param event - The mouse event
     * @param highlight - The highlight
     * @private
     * @returns void
     * @memberof PdfHighlighter
     */
    private onDocumentContextMenu;
    /**
     * Handle the context menu event
     * @param event - The mouse event
     * @param highlight - The highlight
     * @private
     * @returns void
     * @memberof PdfHighlighter
     */
    private onHighlightContextMenu;
    private destroyContextMenu;
    /**
     * Handle the text selection event
     * @private
     * @returns void
     * @memberof PdfHighlighter
     */
    private handleTextSelection;
    /**
     * Handle the scale value of the PDF Viewer
     * @private
     * @returns void
     * @memberof PdfHighlighter
     */
    private handleScaleValue;
    /**
     * Handle the scroll event
     * @private
     * @returns void
     * @memberof PdfHighlighter
     */
    private handleScroll;
    /**
     * Render the highlight layer for a specific page
     * @param highlightBindings - The highlight bindings
     * @param pageNumber - The page number
     * @private
     * @returns void
     * @memberof PdfHighlighter
     */
    private renderHighlightLayer;
}
export { PdfHighlighter };
