/**
 * What type the highlight is. This is the ideal way to determine whether to
 * render it in an AreaHighlight or TextHighlight.
 *
 * @category Enum
 */
export declare enum HighlightType {
    Text = "text",
    Area = "area"
}
export declare enum PdfScalePresets {
    PageActual = "page-actual",
    PageWidth = "page-width",
    PageHeight = "page-height",
    PageFit = "page-fit",
    Auto = "auto"
}
/**
 * The accepted scroll types by the PDF.js viewer.
 *
 * @category Enum
 */
export declare enum PdfScrollType {
    XYZ = "XYZ",
    Fit = "Fit",
    FitV = "FitV"
}
/**
 * A rectangle as measured by the viewport.
 *
 * @category Type
 */
export type LTWH = {
    /** The x coordinate of the top-left of the rectangle. */
    left: number;
    /** The y coordinate of the top-left of the rectangle. */
    top: number;
    /** Width of the rectangle, relative to top left of the viewport. */
    width: number;
    /** Height of the rectangle, relative to top left of the viewport. */
    height: number;
};
/** @category Type */
export type LTWHP = LTWH & {
    /** 1-Indexed page number */
    pageNumber: number;
};
/**
 * A rectangle as measured by the viewport, with normalised coordinates.
 *
 * @category Type
 */
export type ScaledCoordinates = {
    x1: number;
    y1: number;
    x2: number;
    y2: number;
    width: number;
    height: number;
    /** 1-Indexed page number */
    pageNumber: number;
};
/**
 * Position of a Highlight relative to the viewport.
 *
 * @category Type
 */
export type ViewportPosition = {
    /** Bounding rectangle for the entire highlight. */
    boundingRect: LTWHP;
    /** For text highlights, the rectangular highlights for each block of text. */
    rects: Array<LTWHP>;
};
/**
 * Position of a Highlight with normalised coordinates.
 *
 * @category Type
 */
export type ScaledPosition = {
    /** Bounding rectangle for the entire highlight. */
    boundingRect: ScaledCoordinates;
    /** For text highlights, the rectangular highlights for each block of text. */
    rects: Array<ScaledCoordinates>;
    /** Rarely applicable property of whether coordinates should be in PDF coordinate space.  */
    usePdfCoordinates?: boolean;
};
/**
 * The content of a highlight
 *
 * @category Type
 */
export type Content = {
    text?: string;
    image?: string;
};
/**
 * The accepted scale values by the PDF.js viewer.
 * Numeric entries accept floats, e.g. 1.2 = 120%
 *
 * @category Type
 */
export type PdfScaleValue = PdfScalePresets | number;
/**
 * This represents a selected (text/mouse) area that has been turned into a
 * highlight. If you are storing highlights, they should be stored as this type.
 *
 * @category Type
 */
export interface Highlight {
    id?: string;
    type: HighlightType | string;
    content?: Content;
    comment?: string;
    position: ScaledPosition;
}
/**
 * This represents a rendered highlight, with its position defined by the page
 * viewport.
 *
 * @category Type
 */
export type ViewportHighlight<T extends Highlight = Highlight> = Omit<T, "position"> & {
    position: ViewportPosition;
};
/**
 * A PDF.js page representation. This is the reference type for every page in the PdfHighlighter.
 *
 * @category Type
 */
export type Page = {
    node: HTMLElement;
    /** 1-Index page number */
    number: number;
};
/**
 * All the DOM refs for a group of highlights on one page
 *
 * @category Type
 */
export type HighlightBindings = {
    container: Element;
    textLayer: HTMLElement;
};
export type ContextMenuItem = {
    title: string;
    onClick: (event: Event, highlight?: Highlight | undefined) => void;
};
